package HTML::HTML5::Table::Head;

use 5.010;
use namespace::autoclean;
use utf8;

BEGIN {
	$HTML::HTML5::Table::Head::AUTHORITY = 'cpan:TOBYINK';
	$HTML::HTML5::Table::Head::VERSION   = '0.004';
}

use Moose;
extends 'HTML::HTML5::Table::Section';

1;
